==> lstdataprocess128-1.3.0.tar.gz: lstdataprocess128-1.3.0/src/lstdpp128/CrateBoard.h <==
/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://www.osor.eu/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef LSTDPP_BOARD_H
#define LSTDPP_BOARD_H

#include <stdint.h>
#include <iostream>

namespace lstdpp128 {

/**
 * The size of an event in binary format in int32_t words.
 */
static const int EVENT_SIZE_32 = 4;

/**
 * The size of an event in binary format in int8_t words.
 */
static const int EVENT_SIZE_8 = 16;

/**
 * Version of the file.
 * Version 2 : unify boards to have the same timestamp format.
 */
static const int FORMAT_VERSION = 2;

/**
 * Time base.
 */
static const int TIME_BASE = 9;

/**
 * List of different available boards.
 */
enum BoardType {
    CFD                     = 0,
    C1751_PSD               = 1,
    C1724_PHA               = 2,
    C1730_PSD               = 3,
	C1730_PHA               = 4,
    C1740_QDC               = 5,
    C1740_QDIV              = 6,
	C1725_PHA               = 7,
	C1725_PSD               = 8,

    GGPICKUP                = 20,
    MCC                     = 21,
    CAMERA                  = 22,
};

/**
 * The name of the boards.
 */
static const char* BoardTypeName[] = {
    "CFD",                // 0
    "1751 PSD",           // 1
    "1724 PHA",           // 2
    "1730 PSD",           // 3
    "1730 PHA",           // 4
    "1740 QDC",           // 5
    "1740 QDIV",          // 6
	"1725 PHA",           // 7
	"1725 PSD",           // 8

	// 9 ... 19
    "9?", "10?", "11?", "12?", "13?", "14?", "15?", "16?", "17?", "18?", "19?",

	"GGPICKUP",           // 20
	"MCC",                // 21
    "CAMERA"              // 22
};

/**
 * The time relativity of the boards.
 * Only used for lst v1 files.
 */
static int BoardRelativeTime[] = {
		0,				// 0
		0,				// 1
		1,				// 2
		1,				// 3
		1,				// 4
		0,				// 5
		0,				// 6
		1,				// 7
		0,				// 8

		// 9.. 19
		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,

		0,				// 20
		0,				// 21
		0 				// 22
};

/**
 * The time resolution of the boards (nanoseconds).
 */
static uint32_t BoardTimeResolution[] = {
		1,				// 0
		1,				// 1
		10,				// 2
		2,				// 3
		2,				// 4
		16,				// 5
		16,				// 6
		4,				// 7
		4,				// 8

		// 9.. 19
		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,

		10,				// 20
		10,				// 21
		0 				// 22
};

/**
 * The board structure. A board belongs to a unique crate.
 */
struct Board {
	uint16_t eventType;
	uint8_t crate;
	uint16_t nbChannels;
	BoardType boardType;

	Board() : eventType(0), crate(0), nbChannels(0), boardType(CFD) {}
};

/**
 * The crate structure. A crate owns a bunch of boards.
 */
struct Crate {
	uint16_t nbBoards;
	Board* boards;

	Crate() : nbBoards(0), boards(0) {}
};

/**
 * The crate board structure.
 */
struct CrateBoard {
	uint16_t nbCrates;
	Crate* crates;

	CrateBoard() : nbCrates(0), crates(0) {}
};

/**
 * The list mode header.
 */
struct ListModeContext {
	uint32_t version;
	uint32_t timeBase;
	uint32_t nbEvents;
	CrateBoard crateBoard;

	ListModeContext() : version(FORMAT_VERSION), timeBase(TIME_BASE), nbEvents(0) {}
};

/**
 * The global context object.
 */
extern ListModeContext listModeContext;

/**
 * The size of the header.
 */
extern int32_t listModeHeaderSize;

/**
 * Prints the content of the header.
 */
std::ostream& operator<< (std::ostream& os, ListModeContext const & header);

/**
 * Writes the list mode header. Returns a binary string.
 */
std::string writeListModeContextToBinary(const ListModeContext & listModeContext);

/**
 * Reads the list mode header.
 */
uint32_t readListModeContextFromBinary(ListModeContext & listModeContext, uint32_t version, uint32_t timeBase, uint32_t nbEvents, uint32_t nbBoards, uint32_t* data);

/**
 * Releases the data structures of the list mode context.
 */
void releaseListModeContext(ListModeContext & listModeContext);

/**
 * Iterator on the boards.
 */
class BoardIterator {

public:
	BoardIterator();

	uint8_t crate() const;
	uint16_t board() const;

	bool end() const;
	Board & operator* () const;
	bool operator== (BoardIterator const & i) const;
	bool operator!= (BoardIterator const & i) const;
	BoardIterator & operator++ ();

private:
	uint8_t _currentCrate;
	uint16_t _currentBoard;
};

}

#endif

==> lstdataprocess128-1.3.2.tar.gz: lstdataprocess128-1.3.2/src/lstdpp128/CrateBoard.h <==
/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://www.osor.eu/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef LSTDPP_BOARD_H
#define LSTDPP_BOARD_H

#include <stdint.h>
#include <iostream>

namespace lstdpp128 {

/**
 * The size of an event in binary format in int32_t words.
 */
static const int EVENT_SIZE_32 = 4;

/**
 * The size of an event in binary format in int8_t words.
 */
static const int EVENT_SIZE_8 = 16;

/**
 * Version of the file.
 * Version 2 : unify boards to have the same timestamp format.
 */
static const int FORMAT_VERSION = 2;

/**
 * Time base.
 */
static const int TIME_BASE = 9;

/**
 * List of different available boards.
 */
enum BoardType {
    CFD                     = 0,
    C1751_PSD               = 1,
    C1724_PHA               = 2,
    C1730_PSD               = 3,
	C1730_PHA               = 4,
    C1740_QDC               = 5,
    C1740_QDIV              = 6,
	C1725_PHA               = 7,
	C1725_PSD               = 8,

    GGPICKUP                = 20,
    MCC                     = 21,
    CAMERA                  = 22,
	GGDMS					= 23,
	GGFMCPICKUP				= 24
};

/**
 * The name of the boards.
 */
static const char* BoardTypeName[] = {
    "CFD",                // 0
    "1751 PSD",           // 1
    "1724 PHA",           // 2
    "1730 PSD",           // 3
    "1730 PHA",           // 4
    "1740 QDC",           // 5
    "1740 QDIV",          // 6
	"1725 PHA",           // 7
	"1725 PSD",           // 8

	// 9 ... 19
    "9?", "10?", "11?", "12?", "13?", "14?", "15?", "16?", "17?", "18?", "19?",

	"GGPICKUP",           // 20
	"MCC",                // 21
    "CAMERA",             // 22
	"GGDMS",              // 23
	"GGFMCPICKUP"         // 24
};

/**
 * The time relativity of the boards.
 * Only used for lst v1 files.
 */
static int BoardRelativeTime[] = {
		0,				// 0
		0,				// 1
		1,				// 2
		1,				// 3
		1,				// 4
		0,				// 5
		0,				// 6
		1,				// 7
		0,				// 8

		// 9.. 19
		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,

		0,				// 20
		0,				// 21
		0, 				// 22
		0,				// 23
		0				// 24
};

/**
 * The time resolution of the boards (nanoseconds).
 */
static uint32_t BoardTimeResolution[] = {
		1,				// 0
		1,				// 1
		10,				// 2
		2,				// 3
		2,				// 4
		16,				// 5
		16,				// 6
		4,				// 7
		4,				// 8

		// 9.. 19
		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,

		10,				// 20
		10,				// 21
		0, 				// 22
		10,				// 23
		10				// 24
};

/**
 * The board structure. A board belongs to a unique crate.
 */
struct Board {
	uint16_t eventType;
	uint8_t crate;
	uint16_t nbChannels;
	BoardType boardType;

	Board() : eventType(0), crate(0), nbChannels(0), boardType(CFD) {}
};

/**
 * The crate structure. A crate owns a bunch of boards.
 */
struct Crate {
	uint16_t nbBoards;
	Board* boards;

	Crate() : nbBoards(0), boards(0) {}
};

/**
 * The crate board structure.
 */
struct CrateBoard {
	uint16_t nbCrates;
	Crate* crates;

	CrateBoard() : nbCrates(0), crates(0) {}
};

/**
 * The list mode header.
 */
struct ListModeContext {
	uint32_t version;
	uint32_t timeBase;
	uint32_t nbEvents;
	CrateBoard crateBoard;

	ListModeContext() : version(FORMAT_VERSION), timeBase(TIME_BASE), nbEvents(0) {}
};

/**
 * The global context object.
 */
extern ListModeContext listModeContext;

/**
 * The size of the header.
 */
extern int32_t listModeHeaderSize;

/**
 * Prints the content of the header.
 */
std::ostream& operator<< (std::ostream& os, ListModeContext const & header);

/**
 * Writes the list mode header. Returns a binary string.
 */
std::string writeListModeContextToBinary(const ListModeContext & listModeContext);

/**
 * Reads the list mode header.
 */
uint32_t readListModeContextFromBinary(ListModeContext & listModeContext, uint32_t version, uint32_t timeBase, uint32_t nbEvents, uint32_t nbBoards, uint32_t* data);

/**
 * Releases the data structures of the list mode context.
 */
void releaseListModeContext(ListModeContext & listModeContext);

/**
 * Iterator on the boards.
 */
class BoardIterator {

public:
	BoardIterator();

	uint8_t crate() const;
	uint16_t board() const;

	bool end() const;
	Board & operator* () const;
	bool operator== (BoardIterator const & i) const;
	bool operator!= (BoardIterator const & i) const;
	BoardIterator & operator++ ();

private:
	uint8_t _currentCrate;
	uint16_t _currentBoard;
};

}

#endif
